
</br>
</br>
<p align="center"> 
    <img height="80" src="https://raw.githubusercontent.com/Rohan29-AN/vanilla_pay_python/master/assets/logo_VP.png">
</p>
<div align="center"> 
    <p>
        Vanilla Pay Python library simplifies the integration of Vanilla Pay International payment functionalities into your Python applications.
        <h4>
            <a href="">Documentation</a>
            <span> | </span>
            <a href="https://github.com/Rohan29-AN/vanilla_pay_python/issues">Report bugs</a>
            <span> | </span>
            <a href="https://github.com/Rohan29-AN/vanilla_pay_python/fork">Contribute</a>
        </h4>
    </p>
  
</div>


## TODO?
-Documentation
-Publication in the Pypi


## How to contribute ?

- Make a fork of the repository
- Create a Pull Request 

## Contributors

![Image des contributeurs GitHub](https://contrib.rocks/image?repo=Rohan29-AN/vanilla_pay_python)
